*This file builds the basic state data for TCFW
/*
Structure:
	- Draws each individual data set (already cleaned, for the most part)
	- In each draw, restructures to panel (state-year), if appropriate
	- Once all draws are complete, merge all of these files and make basic restrictions (on sample) across the full set
*/

*******************************************************************************
*1. State Tax Change data 
*******************************************************************************
*prep robustness measure that adds other taxes (e.g. corp taxes) to top 10% amount
use "$dtadir_taxsim/tax_changes_national.dta", clear
local billion = 1000000000
g othertaxes_nominal= othertaxes*(`billion'*ngdp)/100 /* Total national change in nominal value of non-income taxes */
keep othertaxes_nominal year
tempfile data_other_taxes
sort year
save `data_other_taxes'

use "$dtadir_taxsim/tax_changes_state.dta", clear

*Add a supplemental measure of top income that includes other tax changes (like corporate changes)
sort year
merge m:1 year using `data_other_taxes'
drop if _merge==2
drop _merge

*Get total tax change in that year
egen total_top_taxchange = total(rich), by(year)
g share_top10 = rich/total_top_taxchange
g top10_othertaxes = share_top10*othertaxes_nominal

local million = 1000000
g top10_nominal=(gdp_state*`million')/100

*Supplemental measure
g top10_plus_othertaxes = rich + exo*top10_othertaxes/(gdp_state*`million')

drop top10_othertaxes share_top10 othertaxes_nominal total_top_taxchange top10_nominal

tempfile data_taxsim_state
sort fips_state year
save `data_taxsim_state'


*******************************************************************************
*2. State Employment Data
*******************************************************************************

use "$dtadir_bls/emp_unemp_pop.dta", clear
rename state_fips fips_state

g ln_emp= ln(emp)
tempfile data_bls_state
sort fips_state year
save `data_bls_state'


*******************************************************************************
*3. State Consumption Data
*******************************************************************************

use "$dtadir_bea/consumption by state.dta", clear 
g ln_c=ln(C*1000000)
label var ln_c "Log Personal consumption expenditures ($)"
rename fips fips_state

g ln_c_durables=ln(C_durables*1000000)
label var ln_c "Log Personal consumption expenditures on durables ($)"

keep fips_state year ln_c 
keep if year>=1997 
tempfile data_C_state
sort fips_state year
save `data_C_state'


*******************************************************************************
*4. State Income Data
*******************************************************************************
use "$dtadir_bea/income by state.dta", clear 
rename fips fips_state

g ln_inc_pers= ln(incomepersonal)
label var ln_inc_pers "Log personal income (in dollars)"

g ln_inc_wagesal= ln(incomewages)
label var ln_inc_wagesal "Log wages and salaries (in dollars)"

rename incometransfers  govtrans
g ln_govtrans=ln(govtrans)

keep fips year ln_inc_pers ln_inc_wagesal ln_govtrans govtrans
tempfile data_inc_state
sort fips_state year
save `data_inc_state'

*STATE GSP
use "$dtadir_bea/gsp_emp_final.dta", clear
rename emplvl emp_bea
keep state_fips year gsp emp_bea
drop if state_fips==11
g ln_gsp=ln(gsp*1000000)

rename state_fips fips_state
tempfile data_st_gsp
sort fips_state year
save `data_st_gsp'


*State Personal Income and Earnings (by Residence)
use "$dtadir_bea/persinc_earnings.dta", clear
drop if fips_state == 11
keep if year >= 1950

tempfile data_st_persinc_earnings
save `data_st_persinc_earnings'


*******************************************************************************
*5. State Labor Market Data
*******************************************************************************

*FULL SAMPLE
*************
use "$dtadir_cps/st_yr-hrs_lfp_wages_fullsample.dta", clear
rename statefip fips_state
keep year fips_state lfp nonlabforce employed counter parttime_emp wage hours hours_atleast48wks epop inctot
label var lfp   "LFP full sample"
label var wage "CPS Wage, full sample"
label var counter "CPS Weight (Employed ==1) full sample"
label var parttime_emp "Part time employment rate full sample; weeks definition"
label var epop "Employees to Population Ratio (differs from employed)"

keep if year>=1977 
tempfile data_cps_fullsample
sort fips_state year
save `data_cps_fullsample'


*FULL SAMPLE BY SKILL GROUP
***********************************
use "$dtadir_cps/st_yr_skill-hrs_lfp_wages_fullsample.dta", clear
rename statefip fips_state
keep year fips_state employed hours wage skilled counter lfp hours_atleast48wks inctot epop

rename hours_atleast48wks hours_48wk

keep if year>=1977 

tab skilled
drop if missing(skilled)

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	rename `var' `var'_skill
}
reshape wide hours* wage employed counter lfp inctot epop, i(fips_state year) j(skilled)

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	label var `var'_skill0 "Unskilled"
	label var `var'_skill1 "Skilled" 
}

tempfile data_cps_skill
sort fips_state year
save `data_cps_skill'


*FULL SAMPLE BY AGE GROUP
***********************************
use "$dtadir_cps/st_yr_age-hrs_lfp_wages_fullsample.dta", clear
rename statefip fips_state
keep year fips_state employed hours wage age_group counter lfp hours_atleast48wks inctot epop

rename hours_atleast48wks hours_48wk

keep if year>=1977 
keep if inlist(age_group, 1, 2) /* 25-45 and 45-60 */

tab age_group

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	rename `var' `var'_age
}
reshape wide hours* wage employed counter lfp inctot epop, i(fips_state year) j(age_group)

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	label var `var'_age1 "25 <= age < 45" 
	label var `var'_age2 "45 <= age < 60"
}

tempfile data_cps_age
sort fips_state year
save `data_cps_age'


*FULL SAMPLE BY AGE GROUP, MEN
***********************************
use "$dtadir_cps/st_yr_sex_age-hrs_lfp_wages_fullsample.dta", clear
rename statefip fips_state
keep year fips_state employed hours wage age_group sex counter lfp hours_atleast48wks inctot epop

rename hours_atleast48wks hours_48wk

keep if year>=1977 
keep if sex == 1 /* Men */
keep if inlist(age_group, 1, 2) /* 25-45 and 45-60 */

tab age_group

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	rename `var' `var'_men_age
}
reshape wide hours* wage employed counter lfp inctot epop, i(fips_state year) j(age_group)

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	label var `var'_men_age1 "Men, 25 <= age < 45" 
	label var `var'_men_age2 "Men, 45 <= age < 60"
}

tempfile data_cps_age_men
sort fips_state year
save `data_cps_age_men'


*FULL SAMPLE BY AGE GROUP, WOMEN
***********************************
use "$dtadir_cps/st_yr_sex_age-hrs_lfp_wages_fullsample.dta", clear
rename statefip fips_state
keep year fips_state employed hours* wage age_group sex counter lfp inctot epop

rename hours_atleast48wks hours_48wk

keep if year>=1977 
keep if sex == 2 /* Women */
keep if inlist(age_group, 1, 2) /* 25-45 and 45-60 */

tab age_group

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	rename `var' `var'_women_age
}
reshape wide hours* wage employed counter lfp inctot epop, i(fips_state year) j(age_group)

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	label var `var'_women_age1 "Women, 25 <= age < 45" 
	label var `var'_women_age2 "Women, 45 <= age < 60"
}

tempfile data_cps_age_women
sort fips_state year
save `data_cps_age_women'


*FULL SAMPLE BY AGE GROUP, SKILLED
***********************************
use "$dtadir_cps/st_yr_skill_age-hrs_lfp_wages_fullsample.dta", clear
keep if skilled==1
rename statefip fips_state
keep year fips_state employed hours wage age_group counter lfp hours_atleast48wks inctot epop

rename hours_atleast48wks hours_48wk

keep if year>=1977 
keep if inlist(age_group, 1, 2) /* 25-45 and 45-60 */

tab age_group

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	rename `var' `var'_age_skill
}
reshape wide hours* wage employed counter lfp inctot epop, i(fips_state year) j(age_group)

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	label var `var'_age_skill1 "Skilled, 25 <= age < 45" 
	label var `var'_age_skill2 "Skilled, 45 <= age < 65"
}

tempfile data_cps_age_sk
sort fips_state year
save `data_cps_age_sk'


*FULL SAMPLE BY AGE GROUP, UNSKILLED
***********************************
use "$dtadir_cps/st_yr_skill_age-hrs_lfp_wages_fullsample.dta", clear
keep if skilled==0
rename statefip fips_state
keep year fips_state employed hours wage age_group counter lfp hours_atleast48wks inctot epop

rename hours_atleast48wks hours_48wk

keep if year>=1977 
keep if inlist(age_group, 1, 2) /* 25-45 and 45-60 */

tab age_group

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	rename `var' `var'_age_unskill
}
reshape wide hours* wage employed counter lfp inctot epop, i(fips_state year) j(age_group)

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	label var `var'_age_unskill1 "Unskilled, 25 <= age < 45" 
	label var `var'_age_unskill2 "Unskilled, 45 <= age < 60"
}

tempfile data_cps_age_unsk
sort fips_state year
save `data_cps_age_unsk'



*FULL SAMPLE BY RACE (WHITE VS NONWHITE)
***********************************
use "$dtadir_cps/st_yr_race-hrs_lfp_wages_fullsample.dta", clear
rename statefip fips_state
keep year fips_state employed hours wage white counter lfp hours_atleast48wks inctot epop

rename hours_atleast48wks hours_48wk

keep if year>=1977 

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	rename `var' `var'_white
}
reshape wide hours* wage employed counter lfp inctot epop, i(fips_state year) j(white)

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	label var `var'_white0 "Non-White"
	label var `var'_white1 "White" 
}

tempfile data_cps_race
sort fips_state year
save `data_cps_race'


*FULL SAMPLE BY SEX (MALE VS FEMALE)
***********************************
use "$dtadir_cps/st_yr_sex-hrs_lfp_wages_fullsample.dta", clear
rename statefip fips_state
keep year fips_state employed hours wage sex counter lfp hours_atleast48wks inctot epop
replace sex = 0 if sex == 2 /* Just reval for simplicity; MALE == 1; FEMALE == 0 */

rename hours_atleast48wks hours_48wk

keep if year>=1977 

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	rename `var' `var'_sex
}
reshape wide hours* wage employed counter lfp inctot epop, i(fips_state year) j(sex)

foreach var in "hours" "wage" "employed" "counter" "lfp" "hours_48wk" "inctot" "epop" {
	label var `var'_sex0 "Female"
	label var `var'_sex1 "Male" 
}

tempfile data_cps_sex
sort fips_state year
save `data_cps_sex'


*******************************************************************************
*6. State Government Transfers
*******************************************************************************
use "$dtadir_bea/income by state.dta", clear 
rename fips fips_state
rename governmentsocialinsurance inc_govtrans

keep fips year inc_govtrans
keep if year>=1970 
tempfile data_govtrans_state
sort fips_state year
save `data_govtrans_state'


*******************************************************************************
*7. State Region Codes
*******************************************************************************

*Currently only using NS-equivalent region codes (see Nakamura & Steinsson, 2014) 

*******************************************************************************
*8. State Minimum Wages
*******************************************************************************
use "$dtadir_minwage/clean_minwage-by-state.dta", clear
rename fips fips_state
rename minw minwage

keep fips_state year minwage
duplicates drop
keep if year >= 1977

tempfile data_minw
sort fips_state year
save `data_minw'


*******************************************************************************
*9. State-Payroll Data
*******************************************************************************
use "$dtadir_qcew/noindustry.dta", clear
rename state_fips fips_state
rename annual_avg_estabs_count est
rename annual_avg_emplvl emp_CBP
rename avg_annual_pay wage_CBP

*Fix a few obs (for fips == 2); assumption is that wage bill grew linearly between the dates (only 3 years missing for 1 state)
ds est emp_CBP wage_CBP
foreach var in `r(varlist)' {

	*First, store floor and ceiling values simply
	sum `var' if fips_state == 2 & year == 1977
	g templow = `r(mean)'
	sum `var' if fips_state == 2 & year == 1981
	g temphi = `r(mean)'
	
	*Replace missing values appropriately
	replace `var' = int(templow + .25*(temphi - templow)) if year == 1978 & fips_state == 2 
	replace `var' = int(templow + .5*(temphi - templow)) if year == 1979 & fips_state == 2
	replace `var' = int(templow + .75*(temphi - templow)) if year == 1980 & fips_state == 2
	
	*Drop temp vars
	drop temp*
	
}
		

*Payroll proxy
g payroll_CBP = wage_CBP*emp_CBP

tempfile data_qcew
sort fips_state year
save `data_qcew'


*******************************************************************************
*10. State Price Data (ACCRA proxy)
*******************************************************************************
*Unweighted
use "$dtadir_accra/ACCRA_state_cpi_full.dta", clear

tempfile data_accra
sort fips_state year
save `data_accra', replace

*Population Weighted (approximate)
use "$dtadir_accra/ACCRA_state_cpi_full_weighted.dta", clear
rename ACCRA_state_cpi ACCRA_state_cpi_weighted

tempfile data_accra_weighted
sort fips_state year
save `data_accra_weighted', replace


*******************************************************************************
*11. State Population Data
*******************************************************************************

use "$dtadir_st_pop/st_pop.dta", clear
rename fips fips_state
rename pop pop_census
tempfile data_st_pop
sort fips_state year
save `data_st_pop'


*******************************************************************************
*12. Component-constant Wages
*******************************************************************************

use "$dtadir_compcons/comp_cons_panel.dta", clear
rename statefip fips_state
g ln_wage_comp_cons = ln(wage_comp_cons)
label var ln_wage_comp_cons "Log Composition-Constant Wage"

keep if year >= 1977
tempfile data_compcons
save `data_compcons', replace


*******************************************************************************
*13. Federal Intergovernmental Spending Per Capita (From Census of Governments)
*******************************************************************************

use "$dtadir_govfin/fed_to_state_ig_panel.dta", clear
rename fipsstate fips_state
keep fips_state year totalfedigrevenue
destring(fips_state), replace

label var totalfedigrevenue "Total Fed Intergovernmental Revenue (Spending) To State"

keep if year >= 1977
tempfile data_govfin
save `data_govfin', replace


*******************************************************************************
*14. National oil prices by year
*******************************************************************************

use "$dtadir_oil/clean_oil.dta", clear

keep if year >= 1977
tempfile data_oil
save `data_oil', replace


*******************************************************************************
*15. Real interest rate by year
*******************************************************************************

use "$dtadir_irate/irate_real.dta", clear

keep if year >= 1977
tempfile data_irate
save `data_irate', replace


*******************************************************************************
*16. NS-equivalent region crosswalk
*******************************************************************************

use "$dtadir_regions/region_fips_xwalk_NS.dta", clear
rename fipsstate fips_state

tempfile data_regions
save `data_regions', replace


*******************************************************************************
*17. Social Insurance (various files)
*******************************************************************************

***State recipients/enrollees (SSI, SNAP, TANF, etc.)
use "$socinsdir/socins_state_recipients.dta", clear

rename state statename /* For xwalk */

merge m:1 statename using "$dtadir_fipsxwalk/fips_statenames_xwalk.dta"
drop if statename == "Foreign"
assert _merge == 3
drop _merge

keep year fips rec_ssi rec_snap rec_tanf rec_afdc en_medicare
replace rec_snap = 0 if missing(rec_snap)
rename fips fips_state

tempfile data_socins_state_recipients
save `data_socins_state_recipients', replace


***OASDI Payments
use "$dtadir_oasdi/oasdi_state_benefits.dta", clear
replace oasdi_ben = oasdi_ben*1000000 /* In millions */
label var oasdi_ben "OASDI Benefits ($)"

rename state statename /* For xwalk */

merge m:1 statename using "$dtadir_fipsxwalk/fips_statenames_xwalk.dta"
drop if statename == "Foreign"
assert _merge == 3
drop _merge

keep fips year oasdi_ben
rename fips fips_state

tempfile data_oasdi
save `data_oasdi', replace


***COLA
use "$dtadir_ssi/ssi_policy_variables.dta", clear
keep year max_individual_own

tempfile data_cola
save `data_cola', replace


***Average federal SSI
use "$dtadir_ssi/ssi_payments.dta", clear
keep year avg_fedadm
keep if year >= 1977

tempfile data_avgfedadm
save `data_avgfedadm', replace


***SNAP national
use "$dtadir_snap/snap_national.dta", clear
keep year exp_benefits beneficiaries avg_benefit

replace beneficiaries = beneficiaries*1000 /* rescale */
replace exp_benefits = exp_benefits*1000000

label var beneficiaries "Food Stamps/SNAP Beneficiaries (number of persons)"
label var exp_benefits "Food Stamps/SNAP SPending for Benefits ($)"

tempfile data_snap_natl
save `data_snap_natl', replace


***SNAP policy
use "$dtadir_snap/snap_policy.dta", clear
keep year max_48DC family_members

g temp_unit = max_48DC if strpos(family_members, "additional unit") != 0
bysort year: egen additional_unit = max(temp_unit)
drop temp_unit
drop if strpos(family_members, "additional unit") != 0 
destring family_members, replace

reshape wide max_48DC, i(year additional_unit) j(family_members)

forv i = 1/8 {
	label var max_48DC`i' "Max SNAP Allotment, `i' family members"
}
label var additional_unit "Additional Max SNAP Allotment for each additional unit over 8"


tempfile data_snap_policy
save `data_snap_policy', replace


***TANF Spending
use "$dtadir_tanf/tanf_spending.dta", clear
keep state_fips year children families avg_transfer 
*If year only has pooled data, drop other data (and keep 1 outlier where data on pool was unretrievable)
drop if children != "pooled" & inlist(year, 1997, 1998, 1999)
drop if children == "pooled" & !inlist(year, 1997, 1998, 1999) & (state_fips != 42 & year != 2002)
drop if (state_fips == 42 & year == 2002) & children != "pooled"
*Take weighted (by #families) average of transfer by fips-year
bysort state_fips year: egen weighted_avg_transfer = wtmean(avg_transfer), weight(families)
*Collapse on this
collapse weighted_avg_transfer, by(state_fips year)
*Relabel/rename and tempfile
rename state_fips fips_state
rename weighted_avg_transfer weighted_avg_tanf
label var weighted_avg_tanf "Weighted nominal average transfers (TANF) per family"

tempfile data_tanf_spending
save `data_tanf_spending', replace


***TANF policy
use "$dtadir_tanf/tanf_policy_variables.dta", clear
keep state_fips year benefit_fam3 /* Assume family size of 3 is the mean*/
rename state_fips fips_state

tempfile data_tanf_policy
save `data_tanf_policy', replace


***AFDC policy
use "$dtadir_afdc/afdc_policy_variables.dta", clear
keep state_fips year avg_payment max_ben_2ch

rename state_fips fips_state
rename avg_payment avg_afdc
rename max_ben_2ch max_ben_2ch_afdc

tempfile data_afdc_policy
save `data_afdc_policy', replace


***Federal poverty line data
import excel "$dtadir_fpl/snap_policy_fpl.xlsx", clear sheet(FPL)
*rename, etc.
keep A-L /* 48 + DC */
drop if _n == 1 /* Empty (mostly) and want next row to restructure more easily */
drop B C
ds 
foreach var in `r(varlist)' { /* Have variables take first value */
     rename `var' `=strtoname(`var'[1])'
}
drop if _n == 1
*Destring
ds
foreach var in `r(varlist)' {
	destring `var', replace
}

*Rename/label FPL categories to more conventional strings
ds year, not
local i = 1
foreach var in `r(varlist)' {
	rename `var' FPL_fam`i' 
	label var FPL_fam`i' "FPL, `i' family members"
	local ++i
}
rename FPL_fam9 FPL_add
label var FPL_add "FPL, additional poverty level over 8 members"

tempfile data_fpl
save `data_fpl', replace


***FMAP data
use "$dtadir_fmap/fmap_transfers.dta", clear
keep state_fips year fmap
rename state_fips fips_state

tempfile data_fmap
save `data_fmap', replace


***Medicaid 
use "$dtadir_medicaid/medicaid_spending_enrollment.dta", clear
keep state_fips year medicaid_recipients medicaid_exp
rename state_fips fips_state

tempfile data_medicaid
save `data_medicaid', replace

***Medicaid vendor payments
use "$dtadir_medicaid/medicaid_exp_vp.dta", clear
keep statefips year medicaid_pay
rename statefips fips_state

tempfile data_medicaid_pay
save `data_medicaid_pay', replace


***Medicare
use "$dtadir_medicare/medicareB_policy_variables.dta", clear
keep year partB_std_prem
drop if year > 2007

tempfile data_medicare
save `data_medicare', replace


*******************************************************************************
*18. Additional Mechanical Policy Controls (various files)
*******************************************************************************

*AFDC change
use "$dtadir_controls/afdc.dta", clear
rename statefips fips_state

tempfile data_afdc_chg
save `data_afdc_chg', replace


*TANF change
use "$dtadir_controls/tanf.dta", clear
rename statefips fips_state

tempfile data_tanf_chg
save `data_tanf_chg', replace


*SNAP change
use "$dtadir_controls/snap.dta", clear
rename statefips fips_state

tempfile data_snap_chg
save `data_snap_chg', replace


*SSI change
use "$dtadir_controls/ssi.dta", clear
rename statefips fips_state

tempfile data_ssi_chg
save `data_ssi_chg', replace


*Medicaid change
use "$dtadir_controls/medicaid.dta", clear
rename statefips fips_state

tempfile data_medicaid_chg
save `data_medicaid_chg', replace



*******************************************************************************
*19. BLS Price Index (Drawn from STMUS Project)
*******************************************************************************

use "$dtadir_cpi_bls/priceBLS.dta", clear
keep fips_state year priceBLS
replace priceBLS = priceBLS/100 /* 0-1 scale instead of 0-100 */

drop if missing(priceBLS)

tempfile data_bls_price
save `data_bls_price', replace


*******************************************************************************
*20. Housing Price Index (Federal Housing Finance Agency)
*******************************************************************************

use "$dtadir_hpi/state_hpi_2013.dta", clear
rename fips fips_state
keep fips_state year hpi

tempfile data_hpi
save `data_hpi', replace


*******************************************************************************
*21. Local CPI (Follow Moretti)
*******************************************************************************

use "$dtadir_local_cpi/local_cpi_panel.dta", clear

merge 1:1 fips_state year using "$dtadir_local_cpi/local_cpi_panel_hpi.dta"
tab _merge
drop _merge
keep if year <= 2007

tempfile data_cpi_final
save `data_cpi_final', replace

*******************************************************************************
*22. Additional CPS income measures (business income, etc.)
*******************************************************************************

use "$dtadir_cps/st_yr-income_panels.dta", clear
rename statefip fips_state

keep if year>=1977 

ds inc*
foreach var in `r(varlist)' {
	g ln_`var' = ln(`var')
}

tempfile data_cps_income
sort fips_state year
save `data_cps_income'


/******************************************/
/*** MERGE STATE DATASETS (DRAWN ABOVE) ***/
/******************************************/

*Start with TAXSIM file
use `data_taxsim_state', clear

/* BLS */

merge 1:1 fips_state year using `data_bls_state'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop _merge

/* BEA */

merge 1:1 fips_state year using `data_C_state'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop _merge

merge 1:1 fips_state year using `data_inc_state'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop _merge

merge 1:1 fips_state year using `data_st_gsp'
tab _merge
table year, c(m _merge)
drop if _merge    ==2
drop _merge

merge 1:1 fips_state year using `data_st_persinc_earnings'
tab _merge
table year, c(m _merge)
drop if _merge    ==2
drop _merge

/* CPS */

merge 1:1 fips_state year using `data_cps_fullsample'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

merge 1:1 fips_state year using `data_cps_skill'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

merge 1:1 fips_state year using `data_cps_age'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

merge 1:1 fips_state year using `data_cps_age_men'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

merge 1:1 fips_state year using `data_cps_age_women'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

merge 1:1 fips_state year using `data_cps_age_sk'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

merge 1:1 fips_state year using `data_cps_age_unsk'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

merge 1:1 fips_state year using `data_cps_race'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

merge 1:1 fips_state year using `data_cps_sex'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge


/* Minimum Wage */

merge 1:1 fips_state year using `data_minw'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

/* QCEW Data */

merge 1:1 fips_state year using `data_qcew'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

/* Price data (by state-year; proxy) */

merge 1:1 fips_state year using `data_accra'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

merge 1:1 fips_state year using `data_accra_weighted'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

/* Population */

merge 1:1 fips_state year using `data_st_pop'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop _merge

/* Composition-Constant Wages */

merge 1:1 fips_state year using `data_compcons'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

/* Gov fin data */

merge 1:1 fips_state year using `data_govfin'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

/* Oil price */

merge m:1 year using `data_oil'
tab _merge
table year, c(m _merge)
drop _merge

/* Interest Rate */

merge m:1 year using `data_irate'
tab _merge
table year, c(m _merge)
drop _merge

/* Region xwalk */

merge m:1 fips_state using `data_regions'
tab _merge
table year, c(m _merge)
drop _merge


/* Social insurance data */

merge 1:1 fips_state year using `data_socins_state_recipients'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

merge m:1 year using `data_avgfedadm'
tab _merge
table year, c(m _merge)
drop _merge

merge m:1 year using `data_snap_natl'
tab _merge
table year, c(m _merge)
drop _merge

merge m:1 year using `data_cola'
tab _merge
table year, c(m _merge)
drop _merge

merge m:1 year using `data_snap_policy'
tab _merge
table year, c(m _merge)
drop _merge

merge 1:1 fips_state year using `data_tanf_spending'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

merge 1:1 fips_state year using `data_tanf_policy'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

merge 1:1 fips_state year using `data_afdc_policy'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

merge m:1 year using `data_fpl'
tab _merge
table year, c(m _merge)
drop _merge

merge 1:1 fips_state year using `data_fmap'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

merge 1:1 fips_state year using `data_medicaid'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

merge m:1 year using `data_medicare'
tab _merge
table year, c(m _merge)
drop _merge

merge 1:1 fips_state year using `data_oasdi'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

merge 1:1 fips_state year using `data_medicaid_pay'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge


/* Additional (mechanical) policy controls */

merge 1:1 fips_state year using `data_afdc_chg'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge


merge 1:1 fips_state year using `data_tanf_chg'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge


merge 1:1 fips_state year using `data_snap_chg'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge


merge 1:1 fips_state year using `data_ssi_chg'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge


merge 1:1 fips_state year using `data_medicaid_chg'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge


/* BLS Price Index (STMUS) */

merge 1:1 fips_state year using `data_bls_price'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

/* Housing Price Index */

merge 1:1 fips_state year using `data_hpi'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

/* Moretti CPI */

merge 1:1 fips_state year using `data_cpi_final'
tab _merge
table year, c(m _merge)
drop if fips_state == 11
drop _merge

/* CPS Additional Income Measures */

merge 1:1 fips_state year using `data_cps_income'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop _merge


/**************************************/
/*** OUTPUT TEMP STATE TCFW DATASET ***/
/**************************************/

*Kill past 2015 (only kills 1 value) and ensure that dc is killed (for consistency)
drop if year > 2015 
drop if fips_state == 11

*unique fips_state
*assert `r(sum)' == 50 /* Ensures 50 unique states before passing */

*Output
save "$dtadir_final/analysis_st_tcfw_unclean.dta", replace
